django_analyses.migrations package — django_analyses 0.0.3 documentation

# django_analyses.migrations package

## Submodules

## django_analyses.migrations.0001_initial module

class `django_analyses.migrations.0001_initial.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('auth', '__first__')]
  `initial` = True
  `operations` = [<CreateModel name='Analysis', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('description', <django.db.models.fields.TextField>), ('title', <django.db.models.fields.CharField>)], options={'verbose_name_plural': 'Analyses', 'ordering': ('title',)}>, <CreateModel name='AnalysisVersion', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('run_method_key', <django.db.models.fields.CharField>), ('fixed_run_method_kwargs', <django.contrib.postgres.fields.jsonb.JSONField>), ('nested_results_attribute', <django.db.models.fields.CharField>), ('analysis', <django.db.models.fields.related.ForeignKey>)], options={'ordering': ('-title',)}>, <CreateModel name='Input', fields=[('id', <django.db.models.fields.AutoField>)], options={'ordering': ('run',)}>, <CreateModel name='InputDefinition', fields=[('id', <django.db.models.fields.AutoField>), ('key', <django.db.models.fields.CharField>), ('required', <django.db.models.fields.BooleanField>), ('description', <django.db.models.fields.TextField>), ('is_configuration', <django.db.models.fields.BooleanField>), ('value_attribute', <django.db.models.fields.CharField>), ('run_method_input', <django.db.models.fields.BooleanField>)], options={'ordering': ('key',)}>, <CreateModel name='Node', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('configuration', <django.contrib.postgres.fields.jsonb.JSONField>), ('analysis_version', <django.db.models.fields.related.ForeignKey>)], options={'ordering': ('-created',), 'unique_together': {('analysis_version', 'configuration')}}>, <CreateModel name='OutputDefinition', fields=[('id', <django.db.models.fields.AutoField>), ('key', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>)], options={'ordering': ('key',)}>, <CreateModel name='Pipeline', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>)], options={'abstract': False}>, <CreateModel name='BooleanInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('default', <django.db.models.fields.BooleanField>), ('is_output_switch', <django.db.models.fields.BooleanField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='DirectoryInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('is_output_directory', <django.db.models.fields.BooleanField>), ('default', <django.db.models.fields.FilePathField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='FileInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='FileOutputDefinition', fields=[('outputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('validate_existence', <django.db.models.fields.BooleanField>)], bases=('django_analyses.outputdefinition',)>, <CreateModel name='FloatOutputDefinition', fields=[('outputdefinition_ptr', <django.db.models.fields.related.OneToOneField>)], bases=('django_analyses.outputdefinition',)>, <CreateModel name='ListInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('element_type', <django.db.models.fields.CharField>), ('min_length', <django.db.models.fields.PositiveIntegerField>), ('max_length', <django.db.models.fields.PositiveIntegerField>), ('default', <django.contrib.postgres.fields.jsonb.JSONField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='NumberInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>)], bases=('django_analyses.input',)>, <CreateModel name='NumberInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='StringInputDefinition', fields=[('inputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('min_length', <django.db.models.fields.IntegerField>), ('max_length', <django.db.models.fields.IntegerField>), ('default', <django.db.models.fields.CharField>), ('dynamic_default', <django.db.models.fields.CharField>), ('choices', <django.contrib.postgres.fields.array.ArrayField>), ('is_output_path', <django.db.models.fields.BooleanField>), ('is_output_switch', <django.db.models.fields.BooleanField>)], bases=('django_analyses.inputdefinition',)>, <CreateModel name='Run', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('analysis_version', <django.db.models.fields.related.ForeignKey>), ('user', <django.db.models.fields.related.ForeignKey>)], options={'ordering': ('-created',)}>, <CreateModel name='Pipe', fields=[('id', <django.db.models.fields.AutoField>), ('base_destination_port', <django.db.models.fields.related.ForeignKey>), ('base_source_port', <django.db.models.fields.related.ForeignKey>), ('destination', <django.db.models.fields.related.ForeignKey>), ('pipeline', <django.db.models.fields.related.ForeignKey>), ('source', <django.db.models.fields.related.ForeignKey>)]>, <CreateModel name='OutputSpecification', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('analysis', <django.db.models.fields.related.ForeignKey>), ('base_output_definitions', <django.db.models.fields.related.ManyToManyField>)], options={'ordering': ('-modified', '-created'), 'get_latest_by': 'modified', 'abstract': False}>, <CreateModel name='Output', fields=[('id', <django.db.models.fields.AutoField>), ('run', <django.db.models.fields.related.ForeignKey>)], options={'ordering': ('run',)}>, <CreateModel name='InputSpecification', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('analysis', <django.db.models.fields.related.ForeignKey>), ('base_input_definitions', <django.db.models.fields.related.ManyToManyField>)], options={'ordering': ('-modified', '-created'), 'get_latest_by': 'modified', 'abstract': False}>, <AddField model_name='input', name='run', field=<django.db.models.fields.related.ForeignKey>>, <CreateModel name='Category', fields=[('id', <django.db.models.fields.AutoField>), ('created', <django_extensions.db.fields.CreationDateTimeField>), ('modified', <django_extensions.db.fields.ModificationDateTimeField>), ('description', <django.db.models.fields.TextField>), ('title', <django.db.models.fields.CharField>), ('parent', <django.db.models.fields.related.ForeignKey>)], options={'verbose_name_plural': 'Categories', 'ordering': ('title',)}>, <AddField model_name='analysisversion', name='input_specification', field=<django.db.models.fields.related.ForeignKey>>, <AddField model_name='analysisversion', name='output_specification', field=<django.db.models.fields.related.ForeignKey>>, <AddField model_name='analysis', name='category', field=<django.db.models.fields.related.ForeignKey>>, <CreateModel name='FloatInputDefinition', fields=[('numberinputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('min_value', <django.db.models.fields.FloatField>), ('max_value', <django.db.models.fields.FloatField>), ('default', <django.db.models.fields.FloatField>)], bases=('django_analyses.numberinputdefinition',)>, <CreateModel name='IntegerInputDefinition', fields=[('numberinputdefinition_ptr', <django.db.models.fields.related.OneToOneField>), ('min_value', <django.db.models.fields.IntegerField>), ('max_value', <django.db.models.fields.IntegerField>), ('default', <django.db.models.fields.IntegerField>)], bases=('django_analyses.numberinputdefinition',)>, <CreateModel name='StringInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.CharField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.input',)>, <CreateModel name='ListInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.contrib.postgres.fields.jsonb.JSONField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.input',)>, <CreateModel name='FloatOutput', fields=[('output_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.FloatField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.output',)>, <CreateModel name='FileOutput', fields=[('output_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.FilePathField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.output',)>, <CreateModel name='FileInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.FilePathField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.input',)>, <CreateModel name='DirectoryInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.FilePathField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.input',)>, <CreateModel name='BooleanInput', fields=[('input_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.BooleanField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.input',)>, <AlterUniqueTogether name='analysisversion', unique_together={('analysis', 'title')}>, <CreateModel name='IntegerInput', fields=[('numberinput_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.IntegerField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.numberinput',)>, <CreateModel name='FloatInput', fields=[('numberinput_ptr', <django.db.models.fields.related.OneToOneField>), ('value', <django.db.models.fields.FloatField>), ('definition', <django.db.models.fields.related.ForeignKey>)], bases=('django_analyses.numberinput',)>]

## Module contents